@@ -1,4 +1,3 @@
-import socketdev
 from typing import TypedDict
 
 
@@ -12,10 +11,12 @@ class Repo(TypedDict):
 
 
 class Repositories:
-    @staticmethod
-    def list() -> dict:
+    def __init__(self, api):
+        self.api = api
+
+    def list(self) -> dict:
         path = "repos"
-        response = socketdev.do_request(path=path)
+        response = self.api.do_request(path=path)
         if response.status_code == 200:
             repos = response.json()
         else:
